==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/interaction/impl/ClassParticipantSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.interaction.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.interaction.ClassParticipant;
import io.ciera.tool.sql.ooaofooa.interaction.ClassParticipantAttributeSet;
import io.ciera.tool.sql.ooaofooa.interaction.ClassParticipantSet;
import io.ciera.tool.sql.ooaofooa.interaction.InteractionParticipantSet;
import io.ciera.tool.sql.ooaofooa.interaction.impl.ClassParticipantAttributeSetImpl;
import io.ciera.tool.sql.ooaofooa.interaction.impl.InteractionParticipantSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.ModelClassSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.ModelClassSetImpl;

import java.util.Arrays;
import java.util.List;


public class ClassParticipantSetImpl extends InstanceSet<ClassParticipantSet,ClassParticipant> implements ClassParticipantSet {

    // attributes
    @Override
    public void setLabel( String m_Label ) throws XtumlException {
        for ( ClassParticipant classparticipant : this ) classparticipant.setLabel( m_Label );
    }
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( ClassParticipant classparticipant : this ) classparticipant.setObj_ID( ref_Obj_ID );
    }
    @Override
    public void setInformalName( String m_InformalName ) throws XtumlException {
        for ( ClassParticipant classparticipant : this ) classparticipant.setInformalName( m_InformalName );
    }
    @Override
    public void setIsFormal( boolean m_isFormal ) throws XtumlException {
        for ( ClassParticipant classparticipant : this ) classparticipant.setIsFormal( m_isFormal );
    }
    @Override
    public void setPart_ID( UniqueId ref_Part_ID ) throws XtumlException {
        for ( ClassParticipant classparticipant : this ) classparticipant.setPart_ID( ref_Part_ID );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( ClassParticipant classparticipant : this ) classparticipant.setDescrip( m_Descrip );
    }


    // selections
    @Override
    public InteractionParticipantSet R930_is_a_InteractionParticipant() throws XtumlException {
        InteractionParticipantSet interactionparticipantset = new InteractionParticipantSetImpl();
        for ( ClassParticipant classparticipant : this ) interactionparticipantset.add( classparticipant.R930_is_a_InteractionParticipant() );
        return interactionparticipantset;
    }
    @Override
    public ClassParticipantAttributeSet R935_may_have_ClassParticipantAttribute() throws XtumlException {
        ClassParticipantAttributeSet classparticipantattributeset = new ClassParticipantAttributeSetImpl();
        for ( ClassParticipant classparticipant : this ) classparticipantattributeset.addAll( classparticipant.R935_may_have_ClassParticipantAttribute() );
        return classparticipantattributeset;
    }
    @Override
    public ModelClassSet R939_represents_ModelClass() throws XtumlException {
        ModelClassSet modelclassset = new ModelClassSetImpl();
        for ( ClassParticipant classparticipant : this ) modelclassset.add( classparticipant.R939_represents_ModelClass() );
        return modelclassset;
    }


    @Override
    public ClassParticipant nullElement() {
        return ClassParticipantImpl.EMPTY_CLASSPARTICIPANT;
    }

    @Override
    public ClassParticipantSet emptySet() {
      return new ClassParticipantSetImpl();
    }

    @Override
    public ClassParticipantSet value() {
        return this;
    }

    @Override
    public List<ClassParticipant> elements() {
        return Arrays.asList(toArray(new ClassParticipant[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/interaction/impl/ClassParticipantSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.interaction.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.interaction.ClassParticipant;
import io.ciera.tool.sql.ooaofooa.interaction.ClassParticipantAttributeSet;
import io.ciera.tool.sql.ooaofooa.interaction.ClassParticipantSet;
import io.ciera.tool.sql.ooaofooa.interaction.InteractionParticipantSet;
import io.ciera.tool.sql.ooaofooa.interaction.impl.ClassParticipantAttributeSetImpl;
import io.ciera.tool.sql.ooaofooa.interaction.impl.InteractionParticipantSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.ModelClassSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.ModelClassSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class ClassParticipantSetImpl extends InstanceSet<ClassParticipantSet,ClassParticipant> implements ClassParticipantSet {

    public ClassParticipantSetImpl() {
    }

    public ClassParticipantSetImpl(Comparator<? super ClassParticipant> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setInformalName( String m_InformalName ) throws XtumlException {
        for ( ClassParticipant classparticipant : this ) classparticipant.setInformalName( m_InformalName );
    }
    @Override
    public void setPart_ID( UniqueId ref_Part_ID ) throws XtumlException {
        for ( ClassParticipant classparticipant : this ) classparticipant.setPart_ID( ref_Part_ID );
    }
    @Override
    public void setLabel( String m_Label ) throws XtumlException {
        for ( ClassParticipant classparticipant : this ) classparticipant.setLabel( m_Label );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( ClassParticipant classparticipant : this ) classparticipant.setDescrip( m_Descrip );
    }
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( ClassParticipant classparticipant : this ) classparticipant.setObj_ID( ref_Obj_ID );
    }
    @Override
    public void setIsFormal( boolean m_isFormal ) throws XtumlException {
        for ( ClassParticipant classparticipant : this ) classparticipant.setIsFormal( m_isFormal );
    }


    // selections
    @Override
    public InteractionParticipantSet R930_is_a_InteractionParticipant() throws XtumlException {
        InteractionParticipantSet interactionparticipantset = new InteractionParticipantSetImpl();
        for ( ClassParticipant classparticipant : this ) interactionparticipantset.add( classparticipant.R930_is_a_InteractionParticipant() );
        return interactionparticipantset;
    }
    @Override
    public ClassParticipantAttributeSet R935_may_have_ClassParticipantAttribute() throws XtumlException {
        ClassParticipantAttributeSet classparticipantattributeset = new ClassParticipantAttributeSetImpl();
        for ( ClassParticipant classparticipant : this ) classparticipantattributeset.addAll( classparticipant.R935_may_have_ClassParticipantAttribute() );
        return classparticipantattributeset;
    }
    @Override
    public ModelClassSet R939_represents_ModelClass() throws XtumlException {
        ModelClassSet modelclassset = new ModelClassSetImpl();
        for ( ClassParticipant classparticipant : this ) modelclassset.add( classparticipant.R939_represents_ModelClass() );
        return modelclassset;
    }


    @Override
    public ClassParticipant nullElement() {
        return ClassParticipantImpl.EMPTY_CLASSPARTICIPANT;
    }

    @Override
    public ClassParticipantSet emptySet() {
      return new ClassParticipantSetImpl();
    }

    @Override
    public ClassParticipantSet emptySet(Comparator<? super ClassParticipant> comp) {
      return new ClassParticipantSetImpl(comp);
    }

    @Override
    public ClassParticipantSet value() {
        return this;
    }

    @Override
    public List<ClassParticipant> elements() {
        return Arrays.asList(toArray(new ClassParticipant[0]));
    }

}
